@@ -775,12 +775,19 @@ def executeCommand(command,objects = []):
     :param objects: List of objects to pass to the command
     :return: Result structure or False
     """
-    args = {
-        "command": command,
-        "objects": [
-            objects
-        ]
-    }
+    args = {}
+    if type(objects) is list:
+        args = {
+            "command": command,
+            "objects": objects
+        }
+    else:
+        args = {
+            "command": command,
+            "objects": [
+                objects
+            ]
+        }
     try:
         res = client.call("ak.wwise.ui.commands.execute", args)
     except Exception as ex:
@@ -825,6 +832,20 @@ def cleanfilePathFromWwise(path):
     cleanMacpath = path.replace("Y:","~").replace('\\', '/')
     return os.path.abspath(os.path.expanduser(cleanMacpath))
 
+def showObjectsInListView(objects = []):
+    """Open the provided list of objects in the Wwise List View
+
+    :param objects: A List of object IDs, paths or type qualified names
+    :return: Result structure or False
+    """
+    try:
+        res = executeCommand("ShowListView",objects)
+    except Exception as ex:
+        print("call error: {}".format(ex))
+        return False
+    else:
+        return res
+
 def setSwitchContainerAssignment(switch,child):
     """Assign a given child object to a given switch (switch container)
 
